Model class
Constructors
Properties
-
dependencies
↔ List<
String> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- modelName ↔ String
-
getter/setter pair
-
properties
↔ List<
ModelProperty> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
className(
) → String -
copyWith(
{String? modelName, List< ModelProperty> ? properties, List<String> ? dependencies}) → Model -
filename(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override